@@ -20,6 +20,8 @@ Generate a session id using something like `openssl rand -hex 32` - keeping it s
 
 You specify the `download_dir` in config or on the command line (with `--download-dir`).
 
-"""
+## Session storage
 
-__version__ = "0.0.3"
+It'll take the "session_id" value and store session data in `~/.config/telegrab/{session_id}`
+
+"""
